@@ -8,7 +8,6 @@
 #'@export
 #'@return See methods.
 #'@family io
-#'@family interface
 #'@examples
 #' file <- system.file(package = 'yamlet', 'extdata','quinidine.csv')
 #' x <- decorate(file)
@@ -30,9 +29,10 @@ io_csv <- function(x, ...)UseMethod('io_csv')
 #'
 #' @param x character file path; passed to \code{\link[csv]{as.csv.character}} (by method dispatch)
 #' @param ext extension for metadata equivalent of x
-#' @param coerce whether to coerce to factor where guide is a list; passed to \code{\link{decorate.data.frame}}
+# @param coerce whether to coerce to factor where guide is a list; passed to \code{\link{decorate.data.frame}}
 #' @param ... passed to \code{\link[csv]{as.csv.character}} and to \code{\link{decorate}}
 #' @export
+#' @keywords internal
 #' @importFrom csv as.csv
 #' @family io
 #' @family interface
@@ -42,7 +42,7 @@ io_csv <- function(x, ...)UseMethod('io_csv')
 io_csv.character <- function(
   x,
   ext = getOption('yamlet_extension', '.yaml'),
-  coerce = getOption('yamlet_coerce', FALSE),
+  #coerce = getOption('yamlet_coerce', FALSE),
   ...
 ){
   d <- csv::as.csv(x, ...)
@@ -51,7 +51,11 @@ io_csv.character <- function(
   if(!file.exists(meta)){
     message('did not find ', meta)
   }else{
-    d <- decorate(d, meta = meta, coerce = coerce, ...)
+    d <- decorate(
+      d,
+      meta = meta,
+      #coerce = coerce,
+      ...)
   }
   d
 }
@@ -69,8 +73,9 @@ io_csv.character <- function(
 #' @param con passed to \code{\link{io_yamlet}}
 #' @param useBytes passed to \code{\link{io_yamlet}}
 #' @param default_keys passed to \code{\link{io_yamlet}}
-#' @param ... passed to \code{\link{write.table}} and to \code{\link{io_yamlet}}
+#' @param ... passed to \code{\link{as.csv}} and to \code{\link{io_yamlet}}
 #' @export
+#' @keywords internal
 #' @importFrom csv as.csv
 #' @family io
 #' @family interface
